@@ -107,6 +107,24 @@
 #define __MALLOC      __attribute__ ((malloc))
 #endif
 
+#if __cplusplus < 201103L
+#define __FINAL
+#define __OVERRIDE
+#define __DELETED
+#define __DELETE_COPY(x)        inline x(const x&);\
+                                inline x& operator=(const x&)
+#define __DELETE_DEFAULTS(x)    inline x();\
+                                __DELETE_COPY(x)    
+#else
+#define __FINAL                 final
+#define __OVERRIDE              override
+#define __DELETED               =delete
+#define __DELETE_COPY(x)        inline x(const x&) =delete;\
+                                inline x& operator=(const x&) =delete
+#define __DELETE_DEFAULTS(x)    inline x() =delete;\
+                                __DELETE_COPY(x)
+#endif
+
 #if __cplusplus <= 199711L && !defined(_MSC_VER) && !defined(__clang__)
 #if defined(__GNUC_MINOR__)
 #define nullptr __null
