@@ -1679,8 +1679,7 @@ public:
      * @param address to store.
      * @return number of bytes stored.
      */
-    inline static unsigned store(struct sockaddr_storage *storage, const struct sockaddr *address)
-        {return copy((struct sockaddr*)storage, address);}
+    static unsigned store(struct sockaddr_storage *storage, const struct sockaddr *address);
 
     /**
      * Store an address into an internet address object.
@@ -1856,6 +1855,9 @@ public:
  */
 class __EXPORT ListenSocket : protected Socket
 {
+private:
+    __DELETE_COPY(ListenSocket);
+
 public:
     /**
      * Create and bind a listener socket.
@@ -1928,6 +1930,9 @@ public:
  */
 class __EXPORT TCPServer : public ListenSocket
 {
+private:
+    __DELETE_DEFAULTS(TCPServer);
+
 public:
     /**
      * Create and bind a tcp server.  This mostly is used to preserve the
